@@ -51,7 +51,7 @@ include_once 'phing/system/util/Register.php';
  * and cleaning up in the end.
  *
  * If you are invoking Phing from an external application, this is still
- * the class to use.  Your applicaiton can invoke the start() method, passing
+ * the class to use.  Your application can invoke the start() method, passing
  * any commandline arguments or additional properties.
  *
  * @author    Andreas Aderhold <andi@binarycloud.com>
@@ -88,6 +88,12 @@ class Phing
     /** Names of classes to add as listeners to project */
     private $listeners = array();
 
+    /**
+     * keep going mode
+     * @var bool $keepGoingMode
+     */
+    private $keepGoingMode = false;
+
     private $loggerClassname = null;
 
     /** The class to handle input (can be only one). */
@@ -476,6 +482,8 @@ class Phing
                         $this->setProperty($prop, $value);
                     }
                 }
+            } elseif ($arg == "-keep-going" || $arg == "-k") {
+                $this->keepGoingMode = true;
             } elseif ($arg == "-longtargets") {
                 self::$definedProps->setProperty('phing.showlongtargets', 1);
             } elseif ($arg == "-projecthelp" || $arg == "-targets" || $arg == "-list" || $arg == "-l" || $arg == "-p") {
@@ -623,6 +631,8 @@ class Phing
             throw $exc;
         }
 
+        $project->setKeepGoingMode($this->keepGoingMode);
+
         $project->setUserProperty("phing.version", $this->getPhingVersion());
 
         $e = self::$definedProps->keys();
@@ -866,7 +876,7 @@ class Phing
     public static function handlePhpError($level, $message, $file, $line)
     {
 
-        // don't want to print supressed errors
+        // don't want to print suppressed errors
         if (error_reporting() > 0) {
 
             if (self::$phpErrorCapture) {
@@ -963,8 +973,11 @@ class Phing
         $msg .= "  -longtargets           show target descriptions during build" . PHP_EOL;
         $msg .= "  -logfile <file>        use given file for log" . PHP_EOL;
         $msg .= "  -logger <classname>    the class which is to perform logging" . PHP_EOL;
+        $msg .= "  -listener <classname>  add an instance of class as a project listener" . PHP_EOL;
         $msg .= "  -f -buildfile <file>   use given buildfile" . PHP_EOL;
         $msg .= "  -D<property>=<value>   use value for given property" . PHP_EOL;
+        $msg .= "  -keep-going, -k        execute all targets that do not depend" . PHP_EOL;
+        $msg .= "                         on failed target(s)" . PHP_EOL;
         $msg .= "  -propertyfile <file>   load all properties from file" . PHP_EOL;
         $msg .= "  -find <file>           search for buildfile towards the root of the" . PHP_EOL;
         $msg .= "                         filesystem and use it" . PHP_EOL;
