@@ -1,7 +1,7 @@
 <?php
 
 /*
- *  $Id: b1f45d4c15bdc1a1209b884a0ea7eb12124a9124 $
+ *  $Id: c86838ed8b7383c2f9c7958e31a7e09b6ae0d02b $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -27,7 +27,7 @@ require_once dirname(__FILE__) . "/Arg.php";
  * Symfony Console Task
  * @author nuno costa <nuno@francodacosta.com>
  * @license GPL
- * @version $Id: b1f45d4c15bdc1a1209b884a0ea7eb12124a9124 $
+ * @version $Id: c86838ed8b7383c2f9c7958e31a7e09b6ae0d02b $
  * @package phing.tasks.ext.symfony
  */
 class SymfonyConsoleTask extends Task
@@ -63,6 +63,12 @@ class SymfonyConsoleTask extends Task
      */
     private $checkreturn = false;
 
+    /**
+     * Is the symfony cli debug mode set? (true by default)
+     * @var boolean
+     */
+    private $debug = true;
+    
     /**
      * sets the symfony console command to execute
      * @param string $command
@@ -121,6 +127,28 @@ class SymfonyConsoleTask extends Task
         $this->checkreturn = (bool) $checkreturn;
     }
 
+    
+    /**
+     * Whether to set the symfony cli debug mode
+     *
+     * @param boolean $debug If the symfony cli debug mode is set
+     *
+     * @return void
+     */
+    public function setDebug($debug)
+    {
+        $this->debug = (bool) $debug;
+    }
+
+    /**
+     * Get if the symfony cli debug mode is set
+     * @return boolean
+     */
+    public function getDebug()
+    {
+        return $this->debug;
+    }
+
     /**
      * appends an arg tag to the arguments stack
      *
@@ -143,12 +171,31 @@ class SymfonyConsoleTask extends Task
         return $this->args;
     }
 
+    /**
+     * Check if the no-debug option was added via args
+     * @return boolean
+     */
+    private function isNoDebugArgPresent()
+    {
+        foreach($this->args as $arg) {
+            if ($arg->getName() == "no-debug") {
+                return true;
+            }
+        }
+        
+        return false;
+    }
+    
     /**
      * Gets the command string to be executed
      * @return string
      */
     public function getCmdString()
     {
+        // Add no-debug arg if it isn't already present
+        if (!$this->debug && !$this->isNoDebugArgPresent()) {
+            $this->createArg()->setName("no-debug");
+        }
         $cmd = array(
             $this->console,
             $this->command,
@@ -160,7 +207,7 @@ class SymfonyConsoleTask extends Task
     }
 
     /**
-     * executes the synfony consile application
+     * executes the synfony console application
      */
     public function main()
     {
