@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: 071e052aef25b376038dd1cf282c338aa5104667 $
+ *  $Id: fff99666d63c88940f9b305c2822856fa00ab5ce $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -26,7 +26,7 @@ require_once 'phing/Task.php';
  * Based on the DocBlox Task
  *
  * @author    Michiel Rook <mrook@php.net>
- * @version   $Id: 071e052aef25b376038dd1cf282c338aa5104667 $
+ * @version   $Id: fff99666d63c88940f9b305c2822856fa00ab5ce $
  * @since     2.4.10
  * @package   phing.tasks.ext.phpdoc
  */
@@ -62,6 +62,12 @@ class PhpDocumentor2Task extends Task
      */
     private $defaultPackageName = "Default";
 
+    /**
+     * Path to the phpDocumentor .phar
+     * @var string
+     */
+    private $pharLocation = '';
+
     /**
      * Nested adder, adds a set of files (nested fileset attribute).
      *
@@ -118,6 +124,14 @@ class PhpDocumentor2Task extends Task
         $this->defaultPackageName = (string) $defaultPackageName;
     }
 
+    /**
+     * @param string $pharLocation
+     */
+    public function setPharLocation($pharLocation)
+    {
+        $this->pharLocation = $pharLocation;
+    }
+
     /**
      * Forces phpDocumentor to be quiet
      * @deprecated
@@ -155,6 +169,7 @@ class PhpDocumentor2Task extends Task
         $wrapper->setTemplate($this->template);
         $wrapper->setTitle($this->title);
         $wrapper->setDefaultPackageName($this->defaultPackageName);
+        $wrapper->setPharLocation($this->pharLocation);
         $wrapper->run();
     }
 }
