@@ -1,6 +1,6 @@
 <?php
 /**
- * $Id: 045b13bcd4a6158c83a1f401640979f39f119e60 $
+ * $Id: 736c93aeebfee971ec02e321baf6e0120d58e937 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -32,7 +32,7 @@ require_once 'phing/util/ExtendedFileStream.php';
  * different packages or testcases since it is a Javadoc like report.
  *
  * @author Michiel Rook <mrook@php.net>
- * @version $Id: 045b13bcd4a6158c83a1f401640979f39f119e60 $
+ * @version $Id: 736c93aeebfee971ec02e321baf6e0120d58e937 $
  * @package phing.tasks.ext.phpunit
  * @since 2.1.0
  */
@@ -40,7 +40,11 @@ class PHPUnitReportTask extends Task
 {
     private $format = "noframes";
     private $styleDir = "";
-    private $toDir = "";
+
+    /**
+     * @var PhingFile
+     */
+    private $toDir;
 
     /**
      * Whether to use the sorttable JavaScript library, defaults to false
@@ -215,13 +219,25 @@ class PHPUnitReportTask extends Task
                         continue;
                     }
 
-                    $namespace = $child->getAttribute('namespace');
-
-                    if ($namespace == '') {
-                        $namespace = 'default';
+                    if ($child->hasAttribute('namespace')) {
+                        $child->setAttribute('package', $child->getAttribute('namespace'));
+                        continue;
                     }
 
-                    $child->setAttribute('package', $namespace);
+                    $package = 'default';
+                    $refClass = new ReflectionClass($child->getAttribute('name'));
+
+                    if (preg_match('/@package\s+(.*)\r?\n/m', $refClass->getDocComment(), $matches)) {
+                        $package = end($matches);
+                    } elseif (method_exists($refClass, 'getNamespaceName')) {
+                        $namespace = $refClass->getNamespaceName();
+
+                        if ($namespace !== '') {
+                            $package = $namespace;
+                        }
+                    }
+
+                    $child->setAttribute('package', trim($package));
                 }
 
                 $rootElement->removeChild($node);
