@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: e092ad3bc1b2a28320f23b721bea34a6c89719c4 $
+ *  $Id: cc81e1eb8ef44a36e9fcc01ff1ce3acc8933f3f3 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -19,7 +19,7 @@
  * <http://phing.info>.
  */
 
-require_once 'phing/types/selectors/SelectorScanner.php'; 
+require_once 'phing/types/selectors/SelectorScanner.php';
 include_once 'phing/util/StringHelper.php';
 include_once 'phing/types/selectors/SelectorUtils.php';
 
@@ -110,10 +110,11 @@ include_once 'phing/types/selectors/SelectorUtils.php';
  * @author   Magesh Umasankar, umagesh@rediffmail.com
  * @author   Andreas Aderhold, andi@binarycloud.com
  *
- * @version   $Id: e092ad3bc1b2a28320f23b721bea34a6c89719c4 $
+ * @version   $Id: cc81e1eb8ef44a36e9fcc01ff1ce3acc8933f3f3 $
  * @package   phing.util
  */
-class DirectoryScanner implements SelectorScanner {
+class DirectoryScanner implements SelectorScanner
+{
 
     /** default set of excludes */
     protected $DEFAULTEXCLUDES = array(
@@ -131,13 +132,13 @@ class DirectoryScanner implements SelectorScanner {
         "**/.svn/**",
         "**/._*",
         "**/.DS_Store",
-    	"**/.darcs",
-    	"**/.darcs/**",
-    	"**/.git",
-    	"**/.git/**",
-    	"**/.gitattributes",
-    	"**/.gitignore",
-    	"**/.gitmodules",
+        "**/.darcs",
+        "**/.darcs/**",
+        "**/.git",
+        "**/.git/**",
+        "**/.gitattributes",
+        "**/.gitignore",
+        "**/.gitmodules",
     );
 
     /** The base directory which should be scanned. */
@@ -148,7 +149,7 @@ class DirectoryScanner implements SelectorScanner {
 
     /** The patterns for the files that should be excluded. */
     protected $excludes = null;
-    
+
     /** Whether to expand/dereference symbolic links, default is false */
     protected $expandSymbolicLinks = false;
 
@@ -190,12 +191,12 @@ class DirectoryScanner implements SelectorScanner {
 
     /** Selectors */
     protected $selectors = null;
-    
+
     protected $filesDeselected;
     protected $dirsDeselected;
-    
+
     /** if there are no deselected files */
-    protected $everythingIncluded = true;        
+    protected $everythingIncluded = true;
 
     /**
      * Does the path match the start of this pattern up to the first "**".
@@ -206,26 +207,31 @@ class DirectoryScanner implements SelectorScanner {
      *
      * pattern=**\a and str=b will yield true.
      *
-     * @param   pattern             the (non-null) pattern to match against
-     * @param   str                 the (non-null) string (path) to match
-     * @param   isCaseSensitive     must matches be case sensitive?
-     * @return  boolean             true if matches, otherwise false
+     * @param string $pattern
+     * @param string $str
+     * @param bool $isCaseSensitive
+     * @internal param the $pattern pattern to match against
+     * @internal param the $str string (path) to match
+     * @internal param must $isCaseSensitive matches be case sensitive?
+     * @return boolean true if matches, otherwise false
      */
-    function matchPatternStart($pattern, $str, $isCaseSensitive = true) {
+    public function matchPatternStart($pattern, $str, $isCaseSensitive = true)
+    {
         return SelectorUtils::matchPatternStart($pattern, $str, $isCaseSensitive);
     }
 
     /**
-     * Matches a path against a pattern. Static
+     * Matches a path against a pattern.
      *
-     * @param pattern            the (non-null) pattern to match against
-     * @param str                the (non-null) string (path) to match
-     * @param isCaseSensitive    must a case sensitive match be done?
+     * @param string $pattern        the (non-null) pattern to match against
+     * @param string $str            the (non-null) string (path) to match
+     * @param bool $isCaseSensitive  must a case sensitive match be done?
      *
-     * @return true when the pattern matches against the string.
-     *         false otherwise.
+     * @return bool true when the pattern matches against the string.
+     *              false otherwise.
      */
-    function matchPath($pattern, $str, $isCaseSensitive = true) {
+    public function matchPath($pattern, $str, $isCaseSensitive = true)
+    {
         return SelectorUtils::matchPath($pattern, $str, $isCaseSensitive);
     }
 
@@ -235,15 +241,16 @@ class DirectoryScanner implements SelectorScanner {
      * '*' which means zero or more characters,
      * '?' which means one and only one character.
      *
-     * @param  pattern the (non-null) pattern to match against
-     * @param  str     the (non-null) string that must be matched against the
-     *                 pattern
+     * @param string $pattern pattern to match against
+     * @param string $str string that must be matched against the
+     *                    pattern
+     * @param bool $isCaseSensitive
      *
      * @return boolean true when the string matches against the pattern,
      *                 false otherwise.
-     * @access public
      */
-    function match($pattern, $str, $isCaseSensitive = true) {
+    public function match($pattern, $str, $isCaseSensitive = true)
+    {
         return SelectorUtils::match($pattern, $str, $isCaseSensitive);
     }
 
@@ -254,7 +261,8 @@ class DirectoryScanner implements SelectorScanner {
      *
      * @param basedir the (non-null) basedir for scanning
      */
-    function setBasedir($_basedir) {
+    public function setBasedir($_basedir)
+    {
         $_basedir = str_replace('\\', DIRECTORY_SEPARATOR, $_basedir);
         $_basedir = str_replace('/', DIRECTORY_SEPARATOR, $_basedir);
         $this->basedir = $_basedir;
@@ -264,18 +272,20 @@ class DirectoryScanner implements SelectorScanner {
      * Gets the basedir that is used for scanning. This is the directory that
      * is scanned recursively.
      *
-     * @return the basedir that is used for scanning
+     * @return string the basedir that is used for scanning
      */
-    function getBasedir() {
+    public function getBasedir()
+    {
         return $this->basedir;
     }
 
     /**
      * Sets the case sensitivity of the file system
      *
-     * @param specifies if the filesystem is case sensitive
+     * @param bool $_isCaseSensitive specifies if the filesystem is case sensitive
      */
-    function setCaseSensitive($_isCaseSensitive) {
+    public function setCaseSensitive($_isCaseSensitive)
+    {
         $this->isCaseSensitive = ($_isCaseSensitive) ? true : false;
     }
 
@@ -286,9 +296,11 @@ class DirectoryScanner implements SelectorScanner {
      *
      * When a pattern ends with a '/' or '\', "**" is appended.
      *
-     * @param includes list of include patterns
+     * @param array $_includes
+     * @internal param list $includes of include patterns
      */
-    function setIncludes($_includes = array()) {
+    public function setIncludes($_includes = array())
+    {
         if (empty($_includes) || is_null($_includes)) {
             $this->includes = null;
         } else {
@@ -311,10 +323,12 @@ class DirectoryScanner implements SelectorScanner {
      *
      * When a pattern ends with a '/' or '\', "**" is appended.
      *
-     * @param excludes list of exclude patterns
+     * @param array $_excludes
+     * @internal param list $excludes of exclude patterns
      */
 
-    function setExcludes($_excludes = array()) {
+    public function setExcludes($_excludes = array())
+    {
         if (empty($_excludes) || is_null($_excludes)) {
             $this->excludes = null;
         } else {
@@ -329,13 +343,13 @@ class DirectoryScanner implements SelectorScanner {
             }
         }
     }
-    
+
     /**
      * Sets whether to expand/dereference symbolic links
      *
-     * @param expandSymbolicLinks boolean value
+     * @param boolean $expandSymbolicLinks
      */
-    function setExpandSymbolicLinks($expandSymbolicLinks)
+    public function setExpandSymbolicLinks($expandSymbolicLinks)
     {
         $this->expandSymbolicLinks = $expandSymbolicLinks;
     }
@@ -345,8 +359,9 @@ class DirectoryScanner implements SelectorScanner {
      * pattern, and don't match any exclude patterns.
      *
      */
-    function scan() {
-    
+    public function scan()
+    {
+
         if ((empty($this->basedir)) || (!@is_dir($this->basedir))) {
             return false;
         }
@@ -367,14 +382,14 @@ class DirectoryScanner implements SelectorScanner {
         $this->dirsExcluded = array();
         $this->dirsDeselected = array();
         $this->filesDeselected = array();
-        
+
         if ($this->isIncluded("")) {
             if (!$this->isExcluded("")) {
                 if ($this->isSelected("", $this->basedir)) {
                     $this->dirsIncluded[] = "";
                 } else {
                     $this->dirsDeselected[] = "";
-                }                
+                }
             } else {
                 $this->dirsExcluded[] = "";
             }
@@ -383,6 +398,7 @@ class DirectoryScanner implements SelectorScanner {
         }
 
         $this->scandir($this->basedir, "", true);
+
         return true;
     }
 
@@ -391,25 +407,26 @@ class DirectoryScanner implements SelectorScanner {
      *
      * Returns immediately if a slow scan has already been requested.
      */
-    protected function slowScan() {
+    protected function slowScan()
+    {
 
         if ($this->haveSlowResults) {
             return;
         }
 
         // copy trie object add CopyInto() method
-        $excl    = $this->dirsExcluded;
+        $excl = $this->dirsExcluded;
         $notIncl = $this->dirsNotIncluded;
 
-        for ($i=0, $_i=count($excl); $i < $_i; $i++) {
+        for ($i = 0, $_i = count($excl); $i < $_i; $i++) {
             if (!$this->couldHoldIncluded($excl[$i])) {
-                $this->scandir($this->basedir.$excl[$i], $excl[$i].DIRECTORY_SEPARATOR, false);
+                $this->scandir($this->basedir . $excl[$i], $excl[$i] . DIRECTORY_SEPARATOR, false);
             }
         }
 
-        for ($i=0, $_i=count($notIncl); $i < $_i; $i++) {
+        for ($i = 0, $_i = count($notIncl); $i < $_i; $i++) {
             if (!$this->couldHoldIncluded($notIncl[$i])) {
-                $this->scandir($this->basedir.$notIncl[$i], $notIncl[$i].DIRECTORY_SEPARATOR, false);
+                $this->scandir($this->basedir . $notIncl[$i], $notIncl[$i] . DIRECTORY_SEPARATOR, false);
             }
         }
 
@@ -421,20 +438,21 @@ class DirectoryScanner implements SelectorScanner {
      *
      * @param   src String. Source path and name file to copy.
      *
-     * @access  public
-     * @return  array  directory entries
+     * @return array directory entries
      * @author  Albert Lash, alash@plateauinnovation.com
      */
 
-    function listDir($_dir) {
+    public function listDir($_dir)
+    {
         $d = dir($_dir);
         $list = array();
-        while(($entry = $d->read()) !== false) {
+        while (($entry = $d->read()) !== false) {
             if ($entry != "." && $entry != "..") {
                 $list[] = $entry;
             }
         }
         $d->close();
+
         return $list;
     }
 
@@ -444,11 +462,13 @@ class DirectoryScanner implements SelectorScanner {
      * matching of includes and excludes. When a directory is found, it is
      * scanned recursively.
      *
-     * @param dir   the directory to scan
-     * @param vpath the path relative to the basedir (needed to prevent
+     * @param $_rootdir
+     * @param $_vpath
+     * @param $_fast
+     * @internal param the $dir directory to scan
+     * @internal param the $vpath path relative to the basedir (needed to prevent
      *              problems with an absolute path when using dir)
      *
-     * @access private
      * @see #filesIncluded
      * @see #filesNotIncluded
      * @see #filesExcluded
@@ -456,21 +476,21 @@ class DirectoryScanner implements SelectorScanner {
      * @see #dirsNotIncluded
      * @see #dirsExcluded
      */
-    private function scandir($_rootdir, $_vpath, $_fast) {
-        
+    private function scandir($_rootdir, $_vpath, $_fast)
+    {
+
         if (!is_readable($_rootdir)) {
             return;
-        }                                
-        
+        }
+
         $newfiles = self::listDir($_rootdir);
-        
-        for ($i=0,$_i=count($newfiles); $i < $_i; $i++) {
-            
+
+        for ($i = 0, $_i = count($newfiles); $i < $_i; $i++) {
+
             $file = $_rootdir . DIRECTORY_SEPARATOR . $newfiles[$i];
             $name = $_vpath . $newfiles[$i];
 
-            if (@is_link($file) && !$this->expandSymbolicLinks)
-            {
+            if (@is_link($file) && !$this->expandSymbolicLinks) {
                 if ($this->isIncluded($name)) {
                     if (!$this->isExcluded($name)) {
                         if ($this->isSelected($name, $file)) {
@@ -478,7 +498,7 @@ class DirectoryScanner implements SelectorScanner {
                         } else {
                             $this->everythingIncluded = false;
                             $this->filesDeselected[] = $name;
-                        }                        
+                        }
                     } else {
                         $this->everythingIncluded = false;
                         $this->filesExcluded[] = $name;
@@ -487,58 +507,58 @@ class DirectoryScanner implements SelectorScanner {
                     $this->everythingIncluded = false;
                     $this->filesNotIncluded[] = $name;
                 }
-            }
-            else
-            if (@is_dir($file)) {
-                if ($this->isIncluded($name)) {
-                    if (!$this->isExcluded($name)) {
-                        if ($this->isSelected($name, $file)) {
-                            $this->dirsIncluded[] = $name;
-                            if ($_fast) {
-                                $this->scandir($file, $name.DIRECTORY_SEPARATOR, $_fast);
+            } else {
+                if (@is_dir($file)) {
+                    if ($this->isIncluded($name)) {
+                        if (!$this->isExcluded($name)) {
+                            if ($this->isSelected($name, $file)) {
+                                $this->dirsIncluded[] = $name;
+                                if ($_fast) {
+                                    $this->scandir($file, $name . DIRECTORY_SEPARATOR, $_fast);
+                                }
+                            } else {
+                                $this->everythingIncluded = false;
+                                $this->dirsDeselected[] = $name;
+                                if ($_fast && $this->couldHoldIncluded($name)) {
+                                    $this->scandir($file, $name . DIRECTORY_SEPARATOR, $_fast);
+                                }
                             }
                         } else {
                             $this->everythingIncluded = false;
-                            $this->dirsDeselected[] = $name;
+                            $this->dirsExcluded[] = $name;
                             if ($_fast && $this->couldHoldIncluded($name)) {
-                                $this->scandir($file, $name.DIRECTORY_SEPARATOR, $_fast);
-                            }                            
-                        }                                                
+                                $this->scandir($file, $name . DIRECTORY_SEPARATOR, $_fast);
+                            }
+                        }
                     } else {
                         $this->everythingIncluded = false;
-                        $this->dirsExcluded[] = $name;
+                        $this->dirsNotIncluded[] = $name;
                         if ($_fast && $this->couldHoldIncluded($name)) {
-                            $this->scandir($file, $name.DIRECTORY_SEPARATOR, $_fast);
+                            $this->scandir($file, $name . DIRECTORY_SEPARATOR, $_fast);
                         }
                     }
-                } else {
-                    $this->everythingIncluded = false;
-                    $this->dirsNotIncluded[] = $name;
-                    if ($_fast && $this->couldHoldIncluded($name)) {
-                        $this->scandir($file, $name.DIRECTORY_SEPARATOR, $_fast);
+
+                    if (!$_fast) {
+                        $this->scandir($file, $name . DIRECTORY_SEPARATOR, $_fast);
                     }
-                }
-                
-                if (!$_fast) {
-                    $this->scandir($file, $name.DIRECTORY_SEPARATOR, $_fast);
-                }
-                
-            } elseif (@is_file($file)) {
-                if ($this->isIncluded($name)) {
-                    if (!$this->isExcluded($name)) {
-                        if ($this->isSelected($name, $file)) {
-                            $this->filesIncluded[] = $name;
+
+                } elseif (@is_file($file)) {
+                    if ($this->isIncluded($name)) {
+                        if (!$this->isExcluded($name)) {
+                            if ($this->isSelected($name, $file)) {
+                                $this->filesIncluded[] = $name;
+                            } else {
+                                $this->everythingIncluded = false;
+                                $this->filesDeselected[] = $name;
+                            }
                         } else {
                             $this->everythingIncluded = false;
-                            $this->filesDeselected[] = $name;
-                        }                        
+                            $this->filesExcluded[] = $name;
+                        }
                     } else {
                         $this->everythingIncluded = false;
-                        $this->filesExcluded[] = $name;
+                        $this->filesNotIncluded[] = $name;
                     }
-                } else {
-                    $this->everythingIncluded = false;
-                    $this->filesNotIncluded[] = $name;
                 }
             }
         }
@@ -547,48 +567,54 @@ class DirectoryScanner implements SelectorScanner {
     /**
      * Tests whether a name matches against at least one include pattern.
      *
-     * @param name the name to match
-     * @return <code>true</code> when the name matches against at least one
-     *         include pattern, <code>false</code> otherwise.
+     * @param $_name
+     * @internal param the $name name to match
+     * @return bool <code>true</code> when the name matches against at least one
      */
-    protected function isIncluded($_name) {
-        for ($i=0, $_i=count($this->includes); $i < $_i; $i++) {
+    protected function isIncluded($_name)
+    {
+        for ($i = 0, $_i = count($this->includes); $i < $_i; $i++) {
             if (DirectoryScanner::matchPath($this->includes[$i], $_name, $this->isCaseSensitive)) {
                 return true;
             }
         }
+
         return false;
     }
 
     /**
      * Tests whether a name matches the start of at least one include pattern.
      *
-     * @param name the name to match
-     * @return <code>true</code> when the name matches against at least one
-     *         include pattern, <code>false</code> otherwise.
+     * @param string $_name the name to match
+     * @return bool <code>true</code> when the name matches against at least one
+     *                           include pattern, <code>false</code> otherwise.
      */
-    protected function couldHoldIncluded($_name) {
+    protected function couldHoldIncluded($_name)
+    {
         for ($i = 0; $i < count($this->includes); $i++) {
             if (DirectoryScanner::matchPatternStart($this->includes[$i], $_name, $this->isCaseSensitive)) {
                 return true;
             }
         }
+
         return false;
     }
 
     /**
      * Tests whether a name matches against at least one exclude pattern.
      *
-     * @param name the name to match
-     * @return <code>true</code> when the name matches against at least one
-     *         exclude pattern, <code>false</code> otherwise.
+     * @param string $_name the name to match
+     * @return bool <code>true</code> when the name matches against at least one
+     *                           exclude pattern, <code>false</code> otherwise.
      */
-    protected function isExcluded($_name) {
+    protected function isExcluded($_name)
+    {
         for ($i = 0; $i < count($this->excludes); $i++) {
             if (DirectoryScanner::matchPath($this->excludes[$i], $_name, $this->isCaseSensitive)) {
                 return true;
             }
         }
+
         return false;
     }
 
@@ -599,8 +625,9 @@ class DirectoryScanner implements SelectorScanner {
      *
      * @return the names of the files
      */
-    function getIncludedFiles() {
-        return $this->filesIncluded;        
+    public function getIncludedFiles()
+    {
+        return $this->filesIncluded;
     }
 
     /**
@@ -609,8 +636,10 @@ class DirectoryScanner implements SelectorScanner {
      *
      * @return the names of the files
      */
-    function getNotIncludedFiles() {
+    public function getNotIncludedFiles()
+    {
         $this->slowScan();
+
         return $this->filesNotIncluded;
     }
 
@@ -622,8 +651,10 @@ class DirectoryScanner implements SelectorScanner {
      * @return the names of the files
      */
 
-    function getExcludedFiles() {
+    public function getExcludedFiles()
+    {
         $this->slowScan();
+
         return $this->filesExcluded;
     }
 
@@ -638,8 +669,10 @@ class DirectoryScanner implements SelectorScanner {
      *
      * @see #slowScan
      */
-    public function getDeselectedFiles() {
-        $this->slowScan();        
+    public function getDeselectedFiles()
+    {
+        $this->slowScan();
+
         return $this->filesDeselected;
     }
 
@@ -651,8 +684,9 @@ class DirectoryScanner implements SelectorScanner {
      * @return the names of the directories
      */
 
-    function getIncludedDirectories() {
-        return $this->dirsIncluded;        
+    public function getIncludedDirectories()
+    {
+        return $this->dirsIncluded;
     }
 
     /**
@@ -662,9 +696,11 @@ class DirectoryScanner implements SelectorScanner {
      *
      * @return the names of the directories
      */
-    function getNotIncludedDirectories() {
+    public function getNotIncludedDirectories()
+    {
         $this->slowScan();
-        return $this->dirsNotIncluded;        
+
+        return $this->dirsNotIncluded;
     }
 
     /**
@@ -678,11 +714,13 @@ class DirectoryScanner implements SelectorScanner {
      *
      * @see #slowScan
      */
-    public function getDeselectedDirectories() {
+    public function getDeselectedDirectories()
+    {
         $this->slowScan();
+
         return $this->dirsDeselected;
     }
-    
+
     /**
      * Get the names of the directories that matched at least one of the include
      * patterns, an matched also at least one of the exclude patterns.
@@ -690,30 +728,35 @@ class DirectoryScanner implements SelectorScanner {
      *
      * @return the names of the directories
      */
-    function getExcludedDirectories() {
+    public function getExcludedDirectories()
+    {
         $this->slowScan();
-        return $this->dirsExcluded;        
+
+        return $this->dirsExcluded;
     }
 
     /**
      * Adds the array with default exclusions to the current exclusions set.
      *
      */
-    function addDefaultExcludes() {
+    public function addDefaultExcludes()
+    {
         //$excludesLength = ($this->excludes == null) ? 0 : count($this->excludes);
-        foreach($this->DEFAULTEXCLUDES as $pattern) {
+        foreach ($this->DEFAULTEXCLUDES as $pattern) {
             $pattern = str_replace('\\', DIRECTORY_SEPARATOR, $pattern);
             $pattern = str_replace('/', DIRECTORY_SEPARATOR, $pattern);
             $this->excludes[] = $pattern;
         }
     }
-    
+
     /**
      * Sets the selectors that will select the filelist.
      *
-     * @param selectors specifies the selectors to be invoked on a scan
+     * @param specifies $selectors
+     * @internal param specifies $selectors the selectors to be invoked on a scan
      */
-    public function setSelectors($selectors) {
+    public function setSelectors($selectors)
+    {
         $this->selectors = $selectors;
     }
 
@@ -721,34 +764,37 @@ class DirectoryScanner implements SelectorScanner {
      * Returns whether or not the scanner has included all the files or
      * directories it has come across so far.
      *
-     * @return <code>true</code> if all files and directories which have
-     *         been found so far have been included.
+     * @return bool <code>true</code> if all files and directories which have
      */
-    public function isEverythingIncluded() {
+    public function isEverythingIncluded()
+    {
         return $this->everythingIncluded;
     }
-        
+
     /**
      * Tests whether a name should be selected.
      *
-     * @param string $name The filename to check for selecting.
-     * @param string $file The full file path.
+     * @param  string  $name The filename to check for selecting.
+     * @param  string  $file The full file path.
      * @return boolean False when the selectors says that the file
-     *         should not be selected, True otherwise.
+     *                      should not be selected, True otherwise.
      */
-    protected function isSelected($name, $file) {
+    protected function isSelected($name, $file)
+    {
         if ($this->selectors !== null) {
             $basedir = new PhingFile($this->basedir);
             $file = new PhingFile($file);
-            if (!$file->canRead())
+            if (!$file->canRead()) {
                 return false;
-            
-            foreach($this->selectors as $selector) {
+            }
+
+            foreach ($this->selectors as $selector) {
                 if (!$selector->isSelected($basedir, $name, $file)) {
                     return false;
                 }
             }
         }
+
         return true;
     }
 
