@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: 4a34bd39f0e32e33de427de3f66d79214c9f8f9b $
+ *  $Id: 080377e722e061a58ba3039adbdb9380000031f7 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -25,7 +25,7 @@
  *
  * @author Hans Lellelid <hans@velum.net>
  * @package phing.util.regexp
- * @version $Id: 4a34bd39f0e32e33de427de3f66d79214c9f8f9b $
+ * @version $Id: 080377e722e061a58ba3039adbdb9380000031f7 $
  */
 interface RegexpEngine
 {
@@ -43,6 +43,30 @@ interface RegexpEngine
      */
     public function getIgnoreCase();
 
+    /**
+     * Sets whether regexp should be applied in multiline mode.
+     * @param boolean $bit
+     */
+    public function setMultiline($bit);
+
+    /**
+     * Gets whether regexp is to be applied in multiline mode.
+     * @return boolean
+     */
+    public function getMultiline();
+
+    /**
+     * Sets the maximum possible replacements for each pattern.
+     * @param int $limit
+     */
+    public function setLimit($limit);
+
+    /**
+     * Returns the maximum possible replacements for each pattern.
+     * @return int
+     */
+    public function getLimit();
+
     /**
      * Matches pattern against source string and sets the matches array.
      * @param  string  $pattern The regex pattern to match.
